@@ -23,9 +23,9 @@ use crate::{
     ext::xmpc::{self, OptComplex, Ordering2, Round2, NEAREST2},
     float::SmallFloat,
     ops::{
-        AddAssignRound, AddFrom, AddFromRound, AssignRound, DivAssignRound, DivFrom, DivFromRound,
-        MulAssignRound, MulFrom, MulFromRound, NegAssign, Pow, PowAssign, PowAssignRound, PowFrom,
-        PowFromRound, SubAssignRound, SubFrom, SubFromRound,
+        AddAssignRound, AddFrom, AddFromRound, AssignRound, CompleteRound, DivAssignRound, DivFrom,
+        DivFromRound, MulAssignRound, MulFrom, MulFromRound, NegAssign, Pow, PowAssign,
+        PowAssignRound, PowFrom, PowFromRound, SubAssignRound, SubFrom, SubFromRound,
     },
     Complex, Float,
 };
@@ -75,7 +75,7 @@ impl AssignRound<NegIncomplete<'_>> for Complex {
 }
 
 arith_binary_self_round! {
-    Complex, Round2, NEAREST2, Ordering2;
+    Complex, (u32, u32), Round2, NEAREST2, Ordering2;
     xmpc::add;
     Add { add }
     AddAssign { add_assign }
@@ -85,7 +85,7 @@ arith_binary_self_round! {
     AddIncomplete
 }
 arith_binary_self_round! {
-    Complex, Round2, NEAREST2, Ordering2;
+    Complex, (u32, u32), Round2, NEAREST2, Ordering2;
     xmpc::sub;
     Sub { sub }
     SubAssign { sub_assign }
@@ -95,7 +95,7 @@ arith_binary_self_round! {
     SubIncomplete
 }
 arith_binary_self_round! {
-    Complex, Round2, NEAREST2, Ordering2;
+    Complex, (u32, u32), Round2, NEAREST2, Ordering2;
     xmpc::mul;
     Mul { mul }
     MulAssign { mul_assign }
@@ -105,7 +105,7 @@ arith_binary_self_round! {
     MulIncomplete
 }
 arith_binary_self_round! {
-    Complex, Round2, NEAREST2, Ordering2;
+    Complex, (u32, u32), Round2, NEAREST2, Ordering2;
     xmpc::div;
     Div { div }
     DivAssign { div_assign }
@@ -115,7 +115,7 @@ arith_binary_self_round! {
     DivIncomplete
 }
 arith_binary_self_round! {
-    Complex, Round2, NEAREST2, Ordering2;
+    Complex, (u32, u32), Round2, NEAREST2, Ordering2;
     xmpc::pow;
     Pow { pow }
     PowAssign { pow_assign }
@@ -126,7 +126,7 @@ arith_binary_self_round! {
 }
 
 arith_commut_round! {
-    Complex, Round2, NEAREST2, Ordering2;
+    Complex, (u32, u32), Round2, NEAREST2, Ordering2;
     xmpc::add_fr;
     Add { add }
     AddAssign { add_assign }
@@ -137,7 +137,7 @@ arith_commut_round! {
     AddFloatIncomplete, AddOwnedFloatIncomplete
 }
 arith_noncommut_round! {
-    Complex, Round2, NEAREST2, Ordering2;
+    Complex, (u32, u32), Round2, NEAREST2, Ordering2;
     xmpc::sub_fr, xmpc::fr_sub;
     Sub { sub }
     SubAssign { sub_assign }
@@ -149,7 +149,7 @@ arith_noncommut_round! {
     SubFromFloatIncomplete, SubFromOwnedFloatIncomplete
 }
 arith_commut_round! {
-    Complex, Round2, NEAREST2, Ordering2;
+    Complex, (u32, u32), Round2, NEAREST2, Ordering2;
     xmpc::mul_fr;
     Mul { mul }
     MulAssign { mul_assign }
@@ -160,7 +160,7 @@ arith_commut_round! {
     MulFloatIncomplete, MulOwnedFloatIncomplete
 }
 arith_noncommut_round! {
-    Complex, Round2, NEAREST2, Ordering2;
+    Complex, (u32, u32), Round2, NEAREST2, Ordering2;
     xmpc::div_fr, xmpc::fr_div;
     Div { div }
     DivAssign { div_assign }
@@ -172,7 +172,7 @@ arith_noncommut_round! {
     DivFromFloatIncomplete, DivFromOwnedFloatIncomplete
 }
 arith_forward_round! {
-    Complex, Round2, NEAREST2, Ordering2;
+    Complex, (u32, u32), Round2, NEAREST2, Ordering2;
     xmpc::pow_fr;
     Pow { pow }
     PowAssign { pow_assign }
@@ -182,7 +182,7 @@ arith_forward_round! {
 }
 #[cfg(feature = "integer")]
 arith_forward_round! {
-    Complex, Round2, NEAREST2, Ordering2;
+    Complex, (u32, u32), Round2, NEAREST2, Ordering2;
     xmpc::pow_z;
     Pow { pow }
     PowAssign { pow_assign }
@@ -192,7 +192,7 @@ arith_forward_round! {
 }
 
 arith_prim_commut_round! {
-    Complex, Round2, NEAREST2, Ordering2;
+    Complex, (u32, u32), Round2, NEAREST2, Ordering2;
     PrimOps::add;
     Add { add }
     AddAssign { add_assign }
@@ -213,7 +213,7 @@ arith_prim_commut_round! {
     f64, AddF64Incomplete;
 }
 arith_prim_noncommut_round! {
-    Complex, Round2, NEAREST2, Ordering2;
+    Complex, (u32, u32), Round2, NEAREST2, Ordering2;
     PrimOps::sub, PrimOps::sub_from;
     Sub { sub }
     SubAssign { sub_assign }
@@ -234,7 +234,7 @@ arith_prim_noncommut_round! {
     f64, SubF64Incomplete, SubFromF64Incomplete;
 }
 arith_prim_commut_round! {
-    Complex, Round2, NEAREST2, Ordering2;
+    Complex, (u32, u32), Round2, NEAREST2, Ordering2;
     PrimOps::mul;
     Mul { mul }
     MulAssign { mul_assign }
@@ -255,7 +255,7 @@ arith_prim_commut_round! {
     f64, MulF64Incomplete;
 }
 arith_prim_noncommut_round! {
-    Complex, Round2, NEAREST2, Ordering2;
+    Complex, (u32, u32), Round2, NEAREST2, Ordering2;
     PrimOps::div, PrimOps::div_from;
     Div { div }
     DivAssign { div_assign }
@@ -276,7 +276,7 @@ arith_prim_noncommut_round! {
     f64, DivF64Incomplete, DivFromF64Incomplete;
 }
 arith_prim_noncommut_round! {
-    Complex, Round2, NEAREST2, Ordering2;
+    Complex, (u32, u32), Round2, NEAREST2, Ordering2;
     PrimOps::pow, PrimOps::pow_from;
     Pow { pow }
     PowAssign { pow_assign }
@@ -299,7 +299,7 @@ arith_prim_noncommut_round! {
 
 #[cfg(feature = "integer")]
 arith_commut_round! {
-    Complex, Round2, NEAREST2, Ordering2;
+    Complex, (u32, u32), Round2, NEAREST2, Ordering2;
     xmpc::add_z;
     Add { add }
     AddAssign { add_assign }
@@ -311,7 +311,7 @@ arith_commut_round! {
 }
 #[cfg(feature = "integer")]
 arith_noncommut_round! {
-    Complex, Round2, NEAREST2, Ordering2;
+    Complex, (u32, u32), Round2, NEAREST2, Ordering2;
     xmpc::sub_z, xmpc::z_sub;
     Sub { sub }
     SubAssign { sub_assign }
@@ -324,7 +324,7 @@ arith_noncommut_round! {
 }
 #[cfg(feature = "integer")]
 arith_commut_round! {
-    Complex, Round2, NEAREST2, Ordering2;
+    Complex, (u32, u32), Round2, NEAREST2, Ordering2;
     xmpc::mul_z;
     Mul { mul }
     MulAssign { mul_assign }
@@ -336,7 +336,7 @@ arith_commut_round! {
 }
 #[cfg(feature = "integer")]
 arith_forward_round! {
-    Complex, Round2, NEAREST2, Ordering2;
+    Complex, (u32, u32), Round2, NEAREST2, Ordering2;
     xmpc::div_z;
     Div { div }
     DivAssign { div_assign }
@@ -346,7 +346,7 @@ arith_forward_round! {
 }
 #[cfg(feature = "rational")]
 arith_commut_round! {
-    Complex, Round2, NEAREST2, Ordering2;
+    Complex, (u32, u32), Round2, NEAREST2, Ordering2;
     xmpc::add_q;
     Add { add }
     AddAssign { add_assign }
@@ -358,7 +358,7 @@ arith_commut_round! {
 }
 #[cfg(feature = "rational")]
 arith_noncommut_round! {
-    Complex, Round2, NEAREST2, Ordering2;
+    Complex, (u32, u32), Round2, NEAREST2, Ordering2;
     xmpc::sub_q, xmpc::q_sub;
     Sub { sub }
     SubAssign { sub_assign }
@@ -371,7 +371,7 @@ arith_noncommut_round! {
 }
 #[cfg(feature = "rational")]
 arith_commut_round! {
-    Complex, Round2, NEAREST2, Ordering2;
+    Complex, (u32, u32), Round2, NEAREST2, Ordering2;
     xmpc::mul_q;
     Mul { mul }
     MulAssign { mul_assign }
@@ -383,7 +383,7 @@ arith_commut_round! {
 }
 #[cfg(feature = "rational")]
 arith_forward_round! {
-    Complex, Round2, NEAREST2, Ordering2;
+    Complex, (u32, u32), Round2, NEAREST2, Ordering2;
     xmpc::div_q;
     Div { div }
     DivAssign { div_assign }
@@ -393,28 +393,28 @@ arith_forward_round! {
 }
 
 arith_prim_exact_round! {
-    Complex, Round2, NEAREST2, Ordering2;
+    Complex, (u32, u32), Round2, NEAREST2, Ordering2;
     xmpc::shl_u32;
     Shl { shl }
     ShlAssign { shl_assign }
     u32, ShlU32Incomplete;
 }
 arith_prim_exact_round! {
-    Complex, Round2, NEAREST2, Ordering2;
+    Complex, (u32, u32), Round2, NEAREST2, Ordering2;
     xmpc::shr_u32;
     Shr { shr }
     ShrAssign { shr_assign }
     u32, ShrU32Incomplete;
 }
 arith_prim_exact_round! {
-    Complex, Round2, NEAREST2, Ordering2;
+    Complex, (u32, u32), Round2, NEAREST2, Ordering2;
     xmpc::shl_i32;
     Shl { shl }
     ShlAssign { shl_assign }
     i32, ShlI32Incomplete;
 }
 arith_prim_exact_round! {
-    Complex, Round2, NEAREST2, Ordering2;
+    Complex, (u32, u32), Round2, NEAREST2, Ordering2;
     xmpc::shr_i32;
     Shr { shr }
     ShrAssign { shr_assign }
@@ -422,7 +422,7 @@ arith_prim_exact_round! {
 }
 
 mul_op_commut_round! {
-    Complex, Round2, NEAREST2, Ordering2;
+    Complex, (u32, u32), Round2, NEAREST2, Ordering2;
     add_mul;
     Add { add }
     AddAssign { add_assign }
@@ -433,7 +433,7 @@ mul_op_commut_round! {
     AddMulIncomplete
 }
 mul_op_noncommut_round! {
-    Complex, Round2, NEAREST2, Ordering2;
+    Complex, (u32, u32), Round2, NEAREST2, Ordering2;
     sub_mul, mul_sub;
     Sub { sub }
     SubAssign { sub_assign }
