@@ -201,8 +201,7 @@ There are two things that can be done with incomplete-computation values:
  1. Assign them to an existing object without unnecessary allocations. This is
     usually achieved using the [`Assign`] trait or a similar method, for example
     <code>int.[assign][Assign::assign]\(incomplete)</code> and
-    <code>float.[assign\_round][ops::AssignRound::assign_round]\(incomplete,
-    [Round][float::Round]::[Up][float::Round::Up])</code>.
+    <code>float.[assign\_round][ops::AssignRound::assign_round]\(incomplete, [Round][float::Round]::[Up][float::Round::Up])</code>.
  2. Convert them to the final value using the [`Complete`] trait, the [`From`]
     trait or a similar method. For example incomplete integers can be completed
     using <code>incomplete.[complete][Complete::complete]\()</code> or
@@ -273,7 +272,7 @@ a dependency inside [*Cargo.toml*]:
 
 ```toml
 [dependencies]
-rug = "1.13"
+rug = "1.14"
 ```
 
 Rug requires rustc version 1.37.0 or later.
@@ -307,7 +306,7 @@ selectively, you can add the dependency like this to [*Cargo.toml*]:
 
 ```toml
 [dependencies.rug]
-version = "1.13"
+version = "1.14"
 default-features = false
 features = ["integer", "float", "rand"]
 ```
@@ -335,7 +334,7 @@ are in the [`ops`] module are provided by the crate.
 [sys]: gmp_mpfr_sys
 */
 #![warn(missing_docs)]
-#![doc(html_root_url = "https://docs.rs/rug/~1.13")]
+#![doc(html_root_url = "https://docs.rs/rug/~1.14")]
 #![doc(html_logo_url = "data:image/svg+xml;base64,
 PD94bWwgdmVyc2lvbj0iMS4wIiBlbmNvZGluZz0iVVRGLTgiPz4KPCEtLSBDcmVhdGVkIHdpdGggSW5rc2NhcGUgKGh0dHA6Ly93
 d3cuaW5rc2NhcGUub3JnLykgLS0+Cjxzdmcgd2lkdGg9IjEyOCIgaGVpZ2h0PSIxMjgiIHZlcnNpb249IjEuMSIgdmlld0JveD0i
@@ -488,7 +487,6 @@ pub trait Assign<Src = Self> {
     fn assign(&mut self, src: Src);
 }
 
-#[cfg(feature = "integer")]
 /**
 Completes an [incomplete-computation value][icv].
 
@@ -497,6 +495,7 @@ Completes an [incomplete-computation value][icv].
 Implementing the trait:
 
 ```rust
+# #[cfg(feature = "integer")] {
 use rug::{Complete, Integer};
 struct LazyPow4<'a>(&'a Integer);
 impl Complete for LazyPow4<'_> {
@@ -507,15 +506,18 @@ impl Complete for LazyPow4<'_> {
 }
 
 assert_eq!(LazyPow4(&Integer::from(3)).complete(), 3i32.pow(4));
+# }
 ```
 
 Completing an [incomplete-computation value][icv]:
 
 ```rust
+# #[cfg(feature = "integer")] {
 use rug::{Complete, Integer};
 let incomplete = Integer::fibonacci(12);
 let complete = incomplete.complete();
 assert_eq!(complete, 144);
+# }
 ```
 
 [icv]: crate#incomplete-computation-values
@@ -526,6 +528,27 @@ pub trait Complete {
 
     /// Completes the operation.
     fn complete(self) -> Self::Completed;
+
+    /// Completes the operation and stores the result in a target.
+    ///
+    /// # Examples
+    ///
+    /// ```rust
+    /// # #[cfg(feature = "integer")] {
+    /// use rug::{Complete, Integer};
+    /// let mut complete = Integer::new();
+    /// Integer::fibonacci(12).complete_into(&mut complete);
+    /// assert_eq!(complete, 144);
+    /// # }
+    /// ```
+    #[inline]
+    fn complete_into<T>(self, target: &mut T)
+    where
+        Self: Sized,
+        T: Assign<Self>,
+    {
+        target.assign(self);
+    }
 }
 
 #[cfg(feature = "integer")]
